@@ -26,7 +26,7 @@ NULL
 globalVariables(c("mod", "event"))
 
 .pkgenv <- new.env(parent = emptyenv())
-stream_types <- c("fst", "feather", "qs", "rds")
+stream_types <- c("fst", "feather", "parquet", "qs", "rds")
 stream_format_classes <- paste0("stream_format_", stream_types)
 names(stream_format_classes) <- stream_types
 .pkgenv$stream_format_classes <- stream_format_classes
